@@ -14,7 +14,7 @@ from flatland import version
 # Configure the expected parameters and actions for the argparse module
 def parse(cl_input):
     parser = argparse.ArgumentParser(description='Flatland model diagram generator')
-    parser.add_argument('-m', '--model', action='store',
+    parser.add_argument('-m', '--model', action='store', default='model.xmm',
                         help='xuml model file name defining model connectivity without any layout information')
     parser.add_argument('-l', '--layout', action='store', default='normal.mss',
                         help='Flatland layout file defining all layout information with light references to model file.')
@@ -35,7 +35,8 @@ def main():
             print(f"Model file: {args.model} specified on command line not found")
             sys.exit()
     else:
-        print("Getting model from standard input")
+        # TODO: Standard input is not yet supported, so this is a placeholder
+        # TODO: Since a default model file is always supplied via argparse above, this clause will never execute
         model_path = sys.stdin
 
     # output file: If no output file is specified, the generated diagram is provided as standard output
@@ -43,6 +44,8 @@ def main():
     if args.diagram:
         diagram_path = Path(args.diagram)
     else:
+        # TODO: Standard output is not yet supported, so this is a placeholder
+        # TODO: Since a default diagram file is always supplied via argparse above, this clause will never execute
         diagram_path = sys.stdout
 
     # Make a Diagnostics directory if it doesn't exist
